CA24-Cl02
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Audio |
clickAndWait | link=Añadir audio file |
type | id_name | Audio CA24-Cl02
select | id_status | label=Publicado
type | id_file | C:\Documents and Settings\mrivera\Escritorio\Merengue\test-data\test-audio.mp3
clickAndWait | _save |
verifyTextPresent | Audio CA24-Cl02 |
click | _selected_action |
select | action | label=Eliminar audio files seleccionado/s
clickAndWait | index |
verifyTextPresent | exact:¿Está seguro? |
verifyTextPresent | exact:¿Está seguro de que quiere borrar los audio file seleccionados? Los siguientes objetos y sus elementos relacionados serán eliminados: |
verifyTextPresent | Audio file: Audio CA24-Cl02 |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |